/* Copyright 2024 by COG9 Enterprises LLC
 * All rights reserved.
 * Title: mail.c
 * Author: Jed Marti
 * Description: Working with the mail directory.
 * Created: Tue Dec  3 21:49:29 2024
 * Revision History:
 */

#include <stdlib.h>
#include <stdio.h>
#include <stdint.h>
#include <string.h>
#include <sys/types.h>
#include <dirent.h>
#include <errno.h>

#include "meshmail.h"

// Where mail messages are stored.
extern char *MailDir;

uint8_t isNumeric(char *s)
/*     Scan a file name to verify it's all numbers.
 * Parameters:
 *   s: file name from directory search.
 * External references: none
 * Returned values: 1 - all characters 0-9, 0 - at least one isn't.
 * Errors detected: none
 */
{
  size_t sl, l;
  sl = strlen(s);
  for (l = 0; l < sl; ++l)
    if (s[l] < '0' || s[l] > '9') return 0;
  return 1;
}

  

int32_t lastEmail(void)
/*     Search the e-mail directory for all files with numeric names. Keep track of the largest
 *   number so that the next new piece that comes in will go to that number.
 * Parameters: none
 * External References:
 *   MailDir: Directory name where the files are stored.
 * Returned value: Largest number or -1 if no files are found.
 * Errors detected: Couldn't open the directory. Causes halt.
 */
{
  int32_t lastn = -1;
  int32_t n;
  DIR     *fh;
  struct dirent* dent;

  // Open the directory.
  if ((fh = opendir(MailDir)) == NULL)
  {
    fprintf(stderr, "%s:%s:%d Could not open mail directory %s\n", __FILE__, __func__, __LINE__,
            MailDir);
    exit(-1);
  }

  // Read all file names.
  while ((dent = readdir(fh)) != NULL)
  {
    if (isNumeric(dent->d_name))
    {
      n = atoi(dent->d_name);
      if (n > lastn) lastn = n;
    }
  }

  // Clean up and return greatest number.
  closedir(fh);
  return lastn;
}


// EOF
