/* Copyright 2024 by COG9 Enterprises LLC
 * All rights reserved.
 * Title: ssmtp.c
 * Author: Jed Marti
 * Description: Verify that we only have one default gateway.
 * Created: Thu Dec 26 10:45:03 2024
 * Revision History:
 */

#include <stdlib.h>
#include <stdio.h>
#include <stdint.h>
#include <string.h>
#include <errno.h>

#include "meshmail.h"

// Noise.
extern uint8_t Noise;

// State machine looking for default.
enum {
      isw,
      isd,
      ise,
      isf,
      isa,
      isu,
      isl};
  
void checkGateways(void)
{
  int32_t rc;
  uint8_t state = isw;
  FILE    *fh;
  int32_t c;
  uint8_t cnt = 0;

  rc = system("ip r >/tmp/mqttipr");
  if (rc != 0)
  {
    fprintf(stderr, "%s:%s:%d default router test fails because %s\n", __FILE__, __func__, __LINE__,
            strerror(errno));
    return;
  }

  if ((fh = fopen("/tmp/mqttipr", "rb")) == NULL)
  {
    fprintf(stderr, "%s:%s:%d Can't open router test output because %s\n", __FILE__, __func__,
            __LINE__, strerror(errno));
    return;
  }

 loop:
  c = fgetc(fh);
  if (c == EOF)
  {
    fclose(fh);
    if (Noise > 0)
      printf("%s:%s:%d Found %d gateway(s)\n", __FILE__, __func__, __LINE__, cnt);
    if (cnt == 0)
      fprintf(stderr, "%s:%s:%d Default router count is 0, could be a problem\n", __FILE__,
              __func__, __LINE__);
    return;
  }

  switch (state) {
  case isw:
    if (c == 'd') state = isd;
    break;

  case isd:
    if (c == 'e') state = ise;
    else state = isw;
    break;

  case ise:
    if (c == 'f') state = isf;
    else state = isw;
    break;

  case isf:
    if (c == 'a') state = isa;
    else state = isw;
    break;

  case isa:
    if (c == 'u') state = isu;
    else state = isw;
    break;

  case isu:
    if (c == 'l') state = isl;
    else state = isw;
    break;

  case isl:
    if (c == 't')
    {
      ++cnt;
      if (cnt > 1)
      {
	fprintf(stderr, "*********************************\n");
	fprintf(stderr, "*        To clean up:           *\n");
	fprintf(stderr, "*  sudo ip route delete default *\n");
	fprintf(stderr, "*********************************\n");
        fclose(fh);
        return;
      }
    }
    state = isw;
    break;

  }
  goto loop;
}


// EOF

    
