/* Copyright 2024 by COG9 Enterprises LLC
 * All rights reserved.
 * Title: tohtml.c
 * Author: Jed Marti
 * Description: Read an e-mail and convert it to HTML.
 * Created: Wed Dec  4 12:29:00 2024
 * Revision History:
 */

#include <stdlib.h>
#include <stdio.h>
#include <stdint.h>
#include <string.h>
#include <errno.h>
#include <time.h>
#include <sys/time.h>

#include "meshmail.h"

extern char *MailDir;

char *date(void)
/*     Return the current date and time as a string.
 * Parameters: none
 * External References: none
 * Returned values: a string.
 * Errors detected: none
 */
{
  time_t ct;
  char   *ctc;
  ct = time(0);
  ctc = ctime(&ct);
  ctc[strlen(ctc) - 1] = 0;
  return ctc;
}


void convertToHTML(int32_t lemn)
/*     Convert a raw message file to HTML for a browser to read. Nothing fancy as the input
 *   is limited to 228 bytes.
 * Parameters:
 *   lemn: The file index number.
 * External References:
 *   MAXPATHLEN: How big can a file name get (ridiculous).
 *   VERSION, RELEASE, PATCH: System version number.
 * Returned values: none
 * Errors detected: Can't read raw file, can't open output file.
 */
{
  FILE *fin;
  FILE *fout;
  char fname[MAXPATHLEN];
  int32_t c;

  // Open the raw text file.
  snprintf(fname, MAXPATHLEN, "%s/%d", MailDir, lemn);
  if ((fin = fopen(fname, "rb")) == NULL)
  {
    fprintf(stderr, "%s:%s:%d Can't open %s for input because %s\n", __FILE__, __func__,
            __LINE__, fname, strerror(errno));
    exit(-1);
  }

  // Open the HTML file and write the prolog.
  snprintf(fname, MAXPATHLEN, "%s/%d.html", MailDir, lemn);
  if ((fout = fopen(fname, "wb")) == NULL)
  {
    fprintf(stderr, "%s:%s:%d Can't open %s for output because %s\n", __FILE__, __func__,
            __LINE__, fname, strerror(errno));
    exit(-1);
  }

  // Prolog.
  fprintf(fout, "<html>\n<head>\n<title> Message %d</title>\n</head>\n<body>\n", lemn);
  //  fprintf(fout, "<!-- %d %s -->\n", lemn, date());
  fprintf(fout, "<H2> Message %d on %s</H2>\n", lemn, date());

  // This is a crude hack. Someday should try and fiddle new lines at least.
  for (c = fgetc(fin); c != EOF; c = fgetc(fin)) fputc(c, fout);
  fprintf(fout, "\n");

  // Return to caller.
  fprintf(fout, "<p><a HREF=\"index.html\"> Back </a>\n");

  // Epilog
  fprintf(fout, "<p> KI7NNP meshmail V%d.%02d.%03d\n", VERSION, RELEASE, PATCH);
  fprintf(fout, "</body>\n</html>\n");

  // Clean up.
  fclose(fin);
  fclose(fout);

}


// EOF
